import{_ as a,d as t}from"./mermaid.core-C1bEM2sZ.chunk.mjs";var s=a((e,n)=>{let o;return n==="sandbox"&&(o=t("#i"+e)),(n==="sandbox"?t(o.nodes()[0].contentDocument.body):t("body")).select(`[id="${e}"]`)},"getDiagramElement");export{s as g};
//# sourceMappingURL=chunk-55IACEB6-zQf05OBI.chunk.mjs.map
