import{l as t}from"./logger-1JHA8kGV.chunk.mjs";function a(){window.OCA=window.OCA??{},window.OCA.Activity={...window.OCA.Activity,__sidebar_actions:window.OCA.Activity?.__sidebar_actions??[],__sidebar_factories:window.OCA.Activity?.__sidebar_factories??[],__sidebar_filters:window.OCA.Activity?.__sidebar_filters??[],registerSidebarAction(i){window.OCA.Activity.__sidebar_actions.push(i),t.debug("Registered new sidebar action")},registerSidebarEntries(i){window.OCA.Activity.__sidebar_factories.push(i),t.debug("Registered new sidebar actions factory")},registerSidebarFilter(i){window.OCA.Activity.__sidebar_filters.push(i)}},t.info("Activity API registered")}function n(){return window.OCA?.Activity?.__sidebar_actions??[]}async function d(i){if(window.OCA?.Activity?.__sidebar_factories===void 0)return[];const r=[];for(const e of window.OCA.Activity.__sidebar_factories)try{r.push(...await e(i))}catch(s){t.error("Error loading additional activity entries",{error:s})}return r}function _(){return window.OCA?.Activity?.__sidebar_filters??[]}export{d as a,n as b,_ as g,a as r};
//# sourceMappingURL=api-mFrM-9qG.chunk.mjs.map
