import{g as f}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as g}from"./basic-DmGfHAMJ.chunk.mjs";function l(e,a){for(var n=0;n<a.length;n++){const t=a[n];if(typeof t!="string"&&!Array.isArray(t)){for(const r in t)if(r!=="default"&&!(r in e)){const i=Object.getOwnPropertyDescriptor(t,r);i&&Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:()=>t[r]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,s;function u(){if(s)return o;s=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/basic" instead of "highlight.js/lib/languages/basic.js"'))}return e(),o=g(),o}var c=u();const p=f(c),j=l({__proto__:null,default:p},[c]);export{j as b};
//# sourceMappingURL=basic.js-Cd5MK9Iw.chunk.mjs.map
