import{g}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as f}from"./ruleslanguage-D_ChJjaX.chunk.mjs";function u(e,a){for(var t=0;t<a.length;t++){const r=a[t];if(typeof r!="string"&&!Array.isArray(r)){for(const n in r)if(n!=="default"&&!(n in e)){const i=Object.getOwnPropertyDescriptor(r,n);i&&Object.defineProperty(e,n,i.get?i:{enumerable:!0,get:()=>r[n]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,s;function c(){if(s)return o;s=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/ruleslanguage" instead of "highlight.js/lib/languages/ruleslanguage.js"'))}return e(),o=f(),o}var l=c();const p=g(l),j=u({__proto__:null,default:p},[l]);export{j as r};
//# sourceMappingURL=ruleslanguage.js-M1lCpaqk.chunk.mjs.map
