import{g as f}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as g}from"./crmsh-Cu5rIRU0.chunk.mjs";function l(e,a){for(var n=0;n<a.length;n++){const r=a[n];if(typeof r!="string"&&!Array.isArray(r)){for(const t in r)if(t!=="default"&&!(t in e)){const i=Object.getOwnPropertyDescriptor(r,t);i&&Object.defineProperty(e,t,i.get?i:{enumerable:!0,get:()=>r[t]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,s;function u(){if(s)return o;s=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/crmsh" instead of "highlight.js/lib/languages/crmsh.js"'))}return e(),o=g(),o}var c=u();const p=f(c),m=l({__proto__:null,default:p},[c]);export{m as c};
//# sourceMappingURL=crmsh.js-DNy2YadJ.chunk.mjs.map
