import{_ as s}from"./mermaid.core-C1bEM2sZ.chunk.mjs";var r=class{constructor(t){this.init=t,this.records=this.init()}static{s(this,"ImperativeState")}reset(){this.records=this.init()}};export{r as I};
//# sourceMappingURL=chunk-QZHKN3VN-152Nrcce.chunk.mjs.map
