import{g as c}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as f}from"./gcode-BU3QtNC8.chunk.mjs";function l(e,a){for(var n=0;n<a.length;n++){const t=a[n];if(typeof t!="string"&&!Array.isArray(t)){for(const r in t)if(r!=="default"&&!(r in e)){const i=Object.getOwnPropertyDescriptor(t,r);i&&Object.defineProperty(e,r,i.get?i:{enumerable:!0,get:()=>t[r]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var o,g;function u(){if(g)return o;g=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/gcode" instead of "highlight.js/lib/languages/gcode.js"'))}return e(),o=f(),o}var s=u();const d=c(s),j=l({__proto__:null,default:d},[s]);export{j as g};
//# sourceMappingURL=gcode.js-CsfqYHRQ.chunk.mjs.map
