/* extracted by css-entry-points-plugin */
@import './text-BrKBJp1J.chunk.css';
@import './NcLoadingIcon-KhuNWNbx.chunk.css';
@import './NcCheckboxRadioSwitch-DJmw98x9-DACj1PYL.chunk.css';
@import './NcNoteCard-CwNXZ4vV-yBro7FL8.chunk.css';
@import './Wrapper-DtEXsk11.chunk.css';
@import './MenuBar-CjY68-25.chunk.css';
@import './Editor-CScVmeSy.chunk.css';