var s,S;function m(){if(S)return s;S=1;function g(t){const n=t.regex,T={$pattern:/[A-Z]+|%/,keyword:["THEN","ELSE","ENDIF","IF","GOTO","DO","WHILE","WH","END","CALL","SUB","ENDSUB","EQ","NE","LT","GT","LE","GE","AND","OR","XOR","%"],built_in:["ATAN","ABS","ACOS","ASIN","COS","EXP","FIX","FUP","ROUND","LN","SIN","SQRT","TAN","EXISTS"]},c=/\b/;function a(o,A){if(o.index===0)return;const i=o.input[o.index-1];i>="0"&&i<="9"||i!=="_"&&A.ignoreMatch()}const e=/[+-]?((\.\d+)|(\d+)(\.\d*)?)/,r=/[GM]\s*\d+(\.\d+)?/,d=/T\s*\d+/,N=/O\s*\d+/,O=/O<.+>/,E=/[ABCUVWXYZ]\s*/,b=/[FHIJKPQRS]\s*/,p=[t.COMMENT(/\(/,/\)/),t.COMMENT(/;/,/$/),t.APOS_STRING_MODE,t.QUOTE_STRING_MODE,t.C_NUMBER_MODE,{scope:"title.function",variants:[{match:n.concat(c,r)},{begin:r,"on:begin":a},{match:n.concat(c,d)},{begin:d,"on:begin":a}]},{scope:"symbol",variants:[{match:n.concat(c,N)},{begin:N,"on:begin":a},{match:n.concat(c,O)},{begin:O,"on:begin":a},{match:/\*\s*\d+\s*$/}]},{scope:"operator",match:/^N\s*\d+/},{scope:"variable",match:/-?#\s*\d+/},{scope:"property",variants:[{match:n.concat(c,E,e)},{begin:n.concat(E,e),"on:begin":a}]},{scope:"params",variants:[{match:n.concat(c,b,e)},{begin:n.concat(b,e),"on:begin":a}]}];return{name:"G-code (ISO 6983)",aliases:["nc"],case_insensitive:!0,disableAutodetect:!0,keywords:T,contains:p}}return s=g,s}export{m as r};
//# sourceMappingURL=gcode-BU3QtNC8.chunk.mjs.map
