import{v as w}from"./preload-helper-DadE4qT2.chunk.mjs";var f={exports:{}},v;function l(){if(v)return f.exports;v=1;function d(s,i=100,a={}){if(typeof s!="function")throw new TypeError(`Expected the first parameter to be a function, got \`${typeof s}\`.`);if(i<0)throw new RangeError("`wait` must not be negative.");const{immediate:m}=typeof a=="boolean"?{immediate:a}:a;let r,c,t,h,n;function p(){const o=r,u=c;return r=void 0,c=void 0,n=s.apply(o,u),n}function g(){const o=Date.now()-h;o<i&&o>=0?t=setTimeout(g,i-o):(t=void 0,m||(n=p()))}const e=function(...o){if(r&&this!==r&&Object.getPrototypeOf(this)===Object.getPrototypeOf(r))throw new Error("Debounced method called with different contexts of the same prototype.");r=this,c=o,h=Date.now();const u=m&&!t;return t||(t=setTimeout(g,i)),u&&(n=p()),n};return Object.defineProperty(e,"isPending",{get(){return t!==void 0}}),e.clear=()=>{t&&(clearTimeout(t),t=void 0)},e.flush=()=>{t&&e.trigger()},e.trigger=()=>{n=p(),e.clear()},e}return f.exports.debounce=d,f.exports=d,f.exports}var y=l();const x=w(y);export{x as d};
//# sourceMappingURL=index-D_vzF9fp.chunk.mjs.map
