import{g as c}from"./emoji-picker-hi3Hwbeu.chunk.mjs";import{r as g}from"./roboconf-BW60Xabs.chunk.mjs";function l(e,a){for(var t=0;t<a.length;t++){const r=a[t];if(typeof r!="string"&&!Array.isArray(r)){for(const n in r)if(n!=="default"&&!(n in e)){const o=Object.getOwnPropertyDescriptor(r,n);o&&Object.defineProperty(e,n,o.get?o:{enumerable:!0,get:()=>r[n]})}}}return Object.freeze(Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}))}var i,f;function u(){if(f)return i;f=1;function e(){e.warned||(e.warned=!0,console.log('Deprecation (warning): Using file extension in specifier is deprecated, use "highlight.js/lib/languages/roboconf" instead of "highlight.js/lib/languages/roboconf.js"'))}return e(),i=g(),i}var s=u();const p=c(s),j=l({__proto__:null,default:p},[s]);export{j as r};
//# sourceMappingURL=roboconf.js-D7iY_skf.chunk.mjs.map
