OC.L10N.register(
    "profile",
    {
    "Profile" : "Perfil",
    "Not found" : "No encontrado",
    "Insert" : "Insertar",
    "You have not added any info yet" : "Aún no has añadido información",
    "{user} has not added any info yet" : "{user} aún no añade información",
    "Error opening the user status modal, try hard refreshing the page" : "Error al abrir la ventana de estado del usuario, intente actualizar la página",
    "Edit Profile" : "Editar perfil",
    "The headline and about sections will show up here" : "El encabezado y la sección Acerca de aparecerán aquí",
    "Profile not found" : "Perfil no encontrado",
    "The profile does not exist." : "El perfil no existe.",
    "Back to %s" : "Volver a %s"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
