import{s as t,c as o,a as s,C as a}from"./chunk-WL4C6EOR-Dw64acf6.chunk.mjs";import{_ as i}from"./mermaid.core-C1bEM2sZ.chunk.mjs";import"./chunk-FMBD7UC4-CZ1ZijUY.chunk.mjs";import"./chunk-JSJVCQXG-BOrbmHPI.chunk.mjs";import"./chunk-55IACEB6-zQf05OBI.chunk.mjs";import"./chunk-KX2RTZJC-DhoTkxRn.chunk.mjs";import"./NcLoadingIcon-CSiR05rb.chunk.mjs";import"./vue.runtime.esm-B7-PK3p1.chunk.mjs";import"./emoji-picker-hi3Hwbeu.chunk.mjs";import"./index-CdM8BgQf.chunk.mjs";import"./index-DCzdQJ7L.chunk.mjs";import"./preload-helper-BorfeO-5.chunk.mjs";var k={parser:s,get db(){return new a},renderer:o,styles:t,init:i(r=>{r.class||(r.class={}),r.class.arrowMarkerAbsolute=r.arrowMarkerAbsolute},"init")};export{k as diagram};
//# sourceMappingURL=classDiagram-v2-RAHNMMFH-gdvMBB2w.chunk.mjs.map
