import{r}from"./preload-helper-DadE4qT2.chunk.mjs";import{d as s,b as n}from"./index-CpK61T8s.chunk.mjs";async function i(a,o={}){try{const t=await s.stat(a,{data:n(),details:!0,...o});return r(t.data)}catch(t){if(t.code==="ERR_CANCELED")return null;throw t}}export{i as f};
//# sourceMappingURL=fileFetcher-DKR1TLAC.chunk.mjs.map
